@@ -1,7 +1,7 @@
 from py3cw.request import Py3CW
 import os
 import logging
-from logging_configuration import logged
+from .logging_configuration import logged
 from . import utils
 from .model import BotShow, Account, DealMarketOrder, DealShow, PieChartDataElement
 from typing import List
