@@ -2,7 +2,7 @@ from .api import get_bot
 from .model import *
 import requests
 import logging
-from logging_configuration import logged
+from .logging_configuration import logged
 import json
 
 
