@@ -3,7 +3,7 @@ import logging
 from .error import ThreeCommasError
 from .model import BotShow
 from typing import List
-from sys_utils import get_parent_function_name
+from .sys_utils import get_parent_function_name
 
 logger = logging.getLogger(__name__)
 
